package HTML::Dojo::common;
1;
__DATA__
__CPAN_COMMON__ iframe_history.html
<!DOCTYPE html PUBLIC "-//W3C//DTD XHTML 1.0 Transitional//EN"
	"http://www.w3.org/TR/xhtml1/DTD/xhtml1-transitional.dtd">

<html xmlns="http://www.w3.org/1999/xhtml" xml:lang="en" lang="en">
<head>
	<title></title>
	<meta http-equiv="Content-Type" content="text/html; charset=utf-8"></meta>
	<script type="text/javascript">
	// <!--
	var noInit = false;
	var domain = "";
	// document.domain = "localhost";
	
	function defineParams(sparams){
		if(sparams){
			var ss = (sparams.indexOf("&amp;") >= 0) ? "&amp;" : "&";
			sparams = sparams.split(ss);
			for(var x=0; x<sparams.length; x++){
				var tp = sparams[x].split("=");
				if(typeof window[tp[0]] != "undefined"){
					window[tp[0]] = ((tp[1]=="true")||(tp[1]=="false")) ? eval(tp[1]) : tp[1];
				}
			}
		}
	}
	
	function init(){
		// parse the query string if there is one to try to get params that
		// we can act on. Also allow params to be in a fragment identifier.
		var query = null;
		var frag = null;
		var url = document.location.href;
		var hashIndex = url.indexOf("#");
		
		//Extract fragment identifier
		if(hashIndex != -1){
			frag = url.substring(hashIndex + 1, url.length);
			url = url.substring(0, hashIndex);
		}

		//Extract querystring
		var parts = url.split("?");
		if(parts.length == 2){
			query = parts[1];
		}

		defineParams(query);
		defineParams(frag);

		if(noInit){ return; }
		if(domain.length > 0){
			document.domain = domain;
		}
		var hasParentDojo = false;
		try{
			hasParentDojo = window.parent != window && window.parent["dojo"];
		}catch(e){
			alert("Initializing iframe_history.html failed. If you are using a cross-domain Dojo build,"
				+ " please save iframe_history.html to your domain and set djConfig.dojoIframeHistoryUrl"
				+ " to the path on your domain to iframe_history.html");
			throw e;
		}

		if(hasParentDojo){
			//Set the page title so IE history shows up with a somewhat correct name.
			document.title = window.parent.document.title;
			
			//Notify parent that we are loaded.
			var pdj = window.parent.dojo;
			if(pdj["undo"] && pdj["undo"]["browser"]){
				pdj.undo.browser.iframeLoaded(null, window.location);
			}
		}

	}
	// -->
	</script>
</head>
<body onload="try{ init(); }catch(e){ alert(e); }">
	<h4>The Dojo Toolkit -- iframe_history.html</h4>

	<p>This file is used in Dojo's back/fwd button management.</p>
</body>
</html>

__CPAN_COMMON__ flash6_gateway.swf
CWS	  xVKsE}H[~E6VobK&!H5p ƫ%U#@UU9rDHV3ӯ.&W{0g9Y `y߆O%"
{"@')ﻂ70%8QZɣrm@~½~.՞0R}y#_IA;isz	K/{aÃBD=ԙ:l_;"</1h,7;	
{0:tD
U  xL/Jy:"HIG縈DҋW=?ԏi<4ڷwYA??S:yr{A@-OO3ty4(}4{@%;`w~"iz6&hv^G	lO3ۋtI-v~]H.Sy"9.f
L`d|RW|EN
H`f7fYm,'Mf;Z\
I9):LQBe|cµ	SFNZ3A
4dlvЕ(LY0IVܭI{`eY;O#8y1sJHْsDk$-g`R}j|.9LD(-R<{Cy0Yӳ&a[L
:Fu<b6Z6'cچTU~(sۤm6mHaZ5`/YZǟa9(OT9@K=GKPy%7kUC2v[+ܜX&1 )y3\!̫
 3VCH[˪W2JɯMb+/ma]jsmX.y}`	JI
1v=7ufҳLn9" K	HE;nI~=$MmKSs+//YqJiVN
nm9/i;<ld'V&EcfE8	ɢߴ?rC}T~&T*d*jKzۊGf	
ϗ wd]0]Wj,tRʵ<F܉*_<Zr&{E:agkX}V'g%
__CPAN_COMMON__ storage_dialog.swf
CWSF~ x;Ypu IER$K	$%Z4`W݁w`[e-eºM%>(ǲ")QR)NYCR#UVURʕJ\Q6B;{~9ʹIN
T7Y1XMNN~ү{V8ΟcպVXd24l ڭ1fby5Ǟa)]~v7[kp e=oZ8PYbK)f9hϙbfƨ(e-p5̛˦).cȨÕ|e넀_7M:!818V7$`'`=	8c+ @}TLwSWa9,
lX6$5[UTlwuUZQ
UmAHv5B.[~P3?@BrS:>6Wo1ⶐ7Mɢ%oVAy}2):ｷ#:0zu>:ppH3 =`M " &Oc$Q
%2q:$;4ƗQΆI}tl\&i@.c'GF'5rΑ9(Eݶ )@tO
9ىnFH;޺b/l_~>b*k_l?opuն݅iy'3@K1˱IB!M`GY/MQ
H|qx)G7+ذ(|0@W|Pvf*h%FYV`kZpߕ1OHWAU`A4m!.z.H O}@:`չSWY1|7=Qz
_ZYR	%ja)K}
 <i<%Lh`Mg1wa3<t`/ 5!:-i0BϭHU_ፘLڽXAbMMAbVcFY0٢]@,4aN
̊^,wcVmżSL^;~^jпnЖ75{`sN1  p3-[*fl֡!^R͑2<)b4~Xmb3ga94٢c'P;	t
#>A6S4!*M?mkDp	&~by1Gl#0fGw=O@ߏ>Sݾww'^Spn5 - ?f-ɦ_T{C B#pb>a@hE f^LqHϻ`#.<{K:ds/}{}{WNö{Nܛ+j2d]=պ$gJo3>Ǐ30{[in[m:Qm~sG?dS5X4v0TfrhOW,r
v:[446e8㳤|pX[}riLl/e}+ 	{ s399e Ά;su퇺<duJD͸2NV1`|ў֝\YTKGIX&q;^d'	9
v9
sY`O`C>ҽl̦gd#{+zɐ$CBZ .f1aSu}Fy
U/93C9ĩmѢ0RPoǟhȱgQvj0A=EyQ]NX̄	\ŀQR'9ghy6" $$rfJLq\&@m=_L⯣e^Řΰ}Hiڙdy&%[!ct)yz^f$3 ޡzD ifX7S.#C$U1K5$]e^l
)lsщR(_ a)x$0L×ɡ\r]qh,ap݁vAfvbP:)Y.,6xŚ6*<Xvr(tXP(9"fș$![pr^6g8>N)s|CJgUJψZ(-^RќW<t1+S=b gigim|zLA0_." (o	ݍ҄Vh
X[5"pKa|! Ԏ̊HRёnoZ2*SF(P
svﺽ{)C,o|xzrDn/sqtŘ4*msX|ލMu\dl\<;4evǜkt+$	@n	)i_9Ś gtrjk5!|Jktĳi`bXm>hɑH
@袊TAcuC2W55_+]f[Fud!shٛ$ĝ9LG^h)we[ʶr{R`l1IhUU,4P:+3o7S1ke٫iAUCnW5YWnOu[Ǔ徭,@8ԲkHk3|ul-j";Q!m{=MJՋ	FRgCV1Qk]lcW	TI<S/v?nf)Ȯc%nnne5nڅ64
$Xơ=-n,j[l!v Wmhשq߬ih
ddQ(|M{਑ ۗMK +K
ŅO![@#tJYqm\YWvE3I*!4}z,!:JGM@]Z7Gr
}Nu9%&MzTK2\UT|4Թ?s*#s+NEm=u`pN;xwzuiXϘRs,92!.<DbRMjjIb)Q3i)֠',K<	*BlG84+ hann8	U[P<b<jHB
$[VMv@rs;:}	Rk\[)$!!G9D]A D~la5}G"O$vv?g;<\EM $y@{.Wp%3>2#	?P0ӨI0 Y56JC汅>[<RZ	{qg9cK9Ք9p֓m'$%>W&G׊%Un#CAG35	$ "Hc6U&1mY1 er%\$<S>·?Z8!R}{=gDݑ/7ܣ|zPiwߍ)F&穢gC#5_N	}I.Ԏ>ZD2T*[XgNLnq$ͣ0{^Ld^uo&~b;e+[iGr\K
\p[edDNKKx*2\WCŬHg`DEaTӳHJRd#K"T,G1>Z
RKҾJ0xŸ\o/΢ Q3"9r4xُ]@-9^X.3beTZK.Wr:˕L[3Ku{BfH@B
$t1Ȝ4<)lF=:D
ϳ>1?@ %駭;*GŞVy*;)_h<ـ`3} Yi$tQŜ'qs`Z¢$zY3Ly@`2֓5>VRDzI6Ɠ9,y-Neo)9ʱ"D9HOP
XD!5ObՅTjQP})Dh
GAc>>ǸGvJv킏Ci>QC'H7Փ!jP=ETTOZCίCkxFwv3	2Lb/88l4W"u󬗈NJvVrd:@dN\pe:sءdYa#9K3uw%ZTY@,[R5Q(gBgLP4QIyXkYn}s	fS19Z؈iUgT~
/TH?rnr!>x1OÞdze;,7+	TF_¿P}C+TJJIgMUZIu(Oz @tSJ\KtnHEH񜢞)ѳا@L|6z%٣dt/YySb	&<㷞ge4{y0ċi/c4`3S,f{xXFG
47T>i'[KMo[o.v[;~\9;÷o߷~osn|?^h@~%	.`&W
	YHZ|XEat@Z	zAG7mobBSo	Z;j	m~7Ə"'
𛤳xCBk>!^~ր7}Onҗ{;ޭ9w<bT=߷vQ KҢo';O!do-c.tv;^qBr	cǤz>C#e61vǫނn}e7^ikroqnQsݧp?4j92#Ϣ֧tsN8F{-OgƜIU)NʅS0J{}.D ?Hg|5WVWXި~dr<V_u\k_AU,>ɡ=|T&5.A!xfy$5fGئyV][H@!Ŀ,AL+OOcݳ2T[ >ڻp͟42z~a;\+uPEw<?kEq)&j4A?kx«p0(tj'X:uiݑ_%vJ7QdXWEƺJvɱZE󭓛Ekғg=lf1w~:ZL|p6Jm
DH$J8=xnʈW<JUK7ldayMXs<l{W_A{7}hGS}%({ zS3\\Ey?g}ނD{BlXz2?
PZѠ3a)'u2[Y`5Zh
_d{(uui=bRb݃[zr`
OonSOېeǁC	>Z/qQI,CutCJut«utMPG#ut٩X-iESo-YLs?*HMVv@޵oQo*8wVޛ@y3? 	WppEJ
!b @$eǫ\2q>Ubgi6=}KQIk7>yymz^w|8+-w@REwo=0_dҼI:=XdqR겜LYM*s
bɅi_iJ1xRxFL0Cv~5pv,^.]HtttmnsV+O*<<j|	ʱV	5  y2ż3тP?IKOUѐPΥYΎLNRmNu~AhU^uqU1gr(DED_	@&*<12ї3)5NB
"&"v ;KYDZ6灁+FR?8vŊ&=D[RwGjL+RydTq5ZE-󅅻uL/B\(͉'+u| ~4S%fJ!s]VE0<5	B˶@?(7+Ư\!z^sr$!ȫPK	
@!c"E@cVY0[dnJ h+C0'"?ͧ~R-,,< E/6DN6P?On<J>:l}aDЬYlOUA9:ǩI:eFT
f`̍Vۉ)}{{&3>K]r%VOG4U`WPE<ۤ*t%6,
)ucs2a7-<K09ҋD
+h7ęx@J)VѵTUs+pIGC+ ҃"/k8;XHj
@֠|iXr\WtHʢKyM$]y={vT/ނr1y	waK.Lu79^_"jq܇5CCe9lm8CX^Đb=ㅝ#fA-CXƻs{ǚb
avY8_$v[>է(ɳ~Eێ9 דw(l!|įIU~bXRZݞ:6Ԓ	|	R${ާ:44B PZp$/HYTpl4'~"隯s7%? -\k٣=
+.9JpC^%rrR	7.X뺂qԭX/j
pxrq:n|d!Ge*S]W$^MjK-(uM[=;sxIJja2v#vEĝV)7[O)=Y=ISZ;&RD|yM8˃#fYVp>" ~5Ͽ}:
$M଼v-UЂA<ĐkA<&~Ȱ=!#y"#wAFtAK56^%1v	9搞29nsHϘCzV5Z|TvkXn8	WK)*@)CucnDof{IKۿ[Ugh<9vFU;E>K!ixm&PP%])IUe?럪	#
[{eoUO4-t;)hcn\Jcƚ9p#Up?\i7_1fRF(81~EHXeF$,\օc]W톯hxg͆Mq$<o <_)5J;
XD}(jxR?0ÎcGjaX@
 >qX­N?	\a-=q]Dl(rU7Blkt6ΆSٌ-b+\歎IxA]f}3}l7S / I$5o6ᵿYyB3r_:^ D`bsKMO 7yN':OME9 cLY5?J~|;I"78B.cMUs,"mR:?g?PPs O<`\Ȟ*9ɂOڮBMC_Z0=7pq'tˎ8ETȗP[E` 
I?~Y}=B_Q_~ATUk*u:BB8?ʡOq83wpšg_qh?ϡ9eK9=C8"V|prIfͲRfy,6S2ple|lE#,,OfyVۤBZ|\s-xV@bW"o`n7h/?/;
15/R?;ҸϰIz!i?/O;.ˢ]Tרש9*KX{~Z|&Lelqȟlqy?l_W)N65{-NDITW@m%q5DPPYBި0PJN$\RcZ7%E2HҿZk1@8P"p~zJ`'39`4`H1Hsv)P3D6%ӡ$SN &vÞ (^G"׊7І9z7G谈Qr1&_y % ҂Q
{nZ2D<!+S4 rXi0S+M>f'0PG
Ђ a!6iZp m
6Z_,ݯd"DAIx~p`PHA~lX)n	|=,8Ҧs_;dS=sKuTX"kDj[\he)\m%A9EkfVrXZ
oHsl[⻂"t{^e08A?$*5&^b'&
̓.zZyoM$p^
.UVsƝ'wj'KQU1ͬ!~4 EvvP<TymPג
%!.`(6K0K	1l`:AYe5˘77)Y/Sl,MVf"+M`ܕFHR6(z|QXdfb`cnTbӢ{ykXb[@]*[Z{ as;SJ^ߦ4N'H+J\NXL~Z}N5g]V}շ	`B6_eڑۣ)4}iR
ݟϩ-4`xx:R +cċHnmjiD}.aj_?6^N	?p̙eGPN3JTop9̡9ȃ<"xeBg@&Udd&s,ˡ97{yrSepP#4fw[2u0#]bJf&rhJv 4L;ბ=vuׄu}*ʭ`Vɍ-9[{~O6:9J2N%QPgXYy2th҇I",60{(CUav4JRgԏC:(~{|q>3#1M02QFdP]@c({Lx\!ћἩ/6$fx[VMքH/,g{BNML]Vxݨt H`X
^dCL^wRS@2[ሾA\OJBYĂh3tQ$G_e s)ϥç,֤*<
Fqs*59Ӌ8?*594B*4B%T+*4B ^V*4BThV*4]zş'
k2s!;.)w=V~un`MZ;vdgVPF]GZkESdR	|
?%n>Jv#Rj77'DȦԢs~9b/$;ڰ7(G:A=G?O S|؄RIvޝn2H
;,ǿ"YpYqَILlYK6VN4dӲol,"fiÛ:t:ܗ[U6\oWK|.mbo
.q4E/zPv_bC*\vЋF:841ƂFLz&-ϖL$D
D	;)	9Yd,(G+x<y6MVԥ̈́$
r"mƈ-@>۽kOwΗF=DbP;8~e6wtͱJnb*&ؤȆfw!PKQs͵Rsmک9`Q"v;Ψ~`YܪVQsͭIu,9=Qރ\{?.,,׫j-c_SV}K<5ˎW"<u)WWKfdHyy%?M#q+꼀(Mw&dΗĥ=X&gf(p]
KE^=2bWe:D+`d$:ՏW4I`4vaÚ[<Q)6=^~,(/3}t&~¹2_*͊oZtnffםYg8S,lhz:"zg`&Ș#bE
O`>*p
4 !K3,ui
1{IQė^]@Ct!wڜ$$0HV:DOHWuYwFי&|dgZXDQfP oM7_u
[)~]JOܝ
*ڝFCA[+~omIzomI*[dr~Kv_hm<yt_?-·xH$9Eaŏ:x?^tU??FX8ci?.~'D;-ΤU#P,gl'@!Ήߠg`1F*]7վ[\c_!CHAiv}sh]KM/ƽDҽth`
22)͕\N.MSE,<
p3f),G<p,h秵e3SY؅P	Hj<ɥ7v͢=
?HZҚ!iO(4\Dt>gYeh|i6B/ndCDlh.@Mm ؂A8؋(ubݘXqP)'X8 (Ks[*i!O0>)d;9
f=PZQ2UfA%;U)9WU:<;:AЭkzAC礧xsƌIeH%RR	ŠII!iVK!I\
H\NڢZ)WߏG7*nC\ֆ0KclF)6KY]hӃBv8+	?
I&ʩ(5MtR`ku傁8DR~)˓'Ph4i0vQ[mq&qHXu/J&ebX<Ѝ$	b#n |WJ	ْ́$O;Dhu?wΫ=ŊǢȽ,aɟ>rې]%1Qo]Ԡ@=p	lonqT*ulkeVF_+O
/ oOXqU<^y
^-ݔxE˳5%ߞs_%pJ)>Crq?g!"yjvqZ\*WdLyXU-aH%U2X)T' 
@l-Yt@A,tfׇ񖮅+\U0a~yDKMc;Oi&dAH`_CĞU̩kPvB*70«MƥrpVU.ǘ۳v,Tg!d\:YeU%KGGeUvdXAm)&f;NleGfYe̲.6:pbWu>|o7JG$b!XG߫Nku3,K0yknoCSsio>-1
i6,׎j˗N&z/EgwyA!k0N-RUˬ&!e$fYKĊ7HZsĘ(f98;oeNK#abUD,#Z
gyr`.XAC3X^־~1o&w vΐFq&U49m?{wh ;^@`E4x]~G*/ȹq
GަpmH$=M-#ؕZq24T%Z nW5쏟esLRP
hACB&8ܯccl@\el05$s<xF#׮DkģVyccO6R$).X[HAh	,"|ǼbUŮܮt/5<(mXPx;PW(jI'J$]kx<ζmzn87G9MGUEfEcj|_c`cǩR!>ˍwkā)ilP3zyסeHrySvbEhPԦ
FGK!G$֙pt}
A˗	hyX~GjՁtgAv{ayJ45D/lH|i4/&T[`è%i	u$GqX/Nh KH ԥUN86xB5R8 s7;En}uС5Fc6c2< ᓄXipv􋚕C?4?4-IZ?)aЅV׮13<z2v(o6|#ߵЁ޵/s1y蓧i3(.yg`o¿P#p-]&:<+{TH4.ിCDvN)#Dd2/"2"^D+"{ed쓑"6Eg.eD%AdJvJaC"gP 	n>D&ʇaS3"02!Us?}[8/N[{
Ux#;(u++S[Vեƕ I9	+)mۙ"9Ӭ"`ӋYxU<!b2O䏏<3t쑜-༝3
Ke}@fy~2ʫiXvdx6ȣH畹8VN*7Jt>]u	~Z" @ljú&AƬd8> 9إrl#5AYBŞ	@h
Gןvϸm]~4G^\\/h6+ZUSlaNOS|%]}DR"G)0AI}OUt>C,sPsvxG>0EN JXt7!!s])uͳH
xsc"2/CN
\|9p9qr1p-,MZOIE|@G+;z,8E҆p_+OA@|>
e忄VZ<tjg̏VDZp"]stBE;cq沂~2؆˸zII7meܣثӳ!2*EQC]0#GDgbڥRJ⯧gS-7\*Ns>.-̗XF@Cg*K
R@(pp#rcStXy|/\+̓\iP #ԉH:	u:BSψ,_S\(g7BP`X-ϧfJ
	jhxF^5sj\toBC}tS)LOA@K9
H,xqf8~TYLѻىpfyAҚ))d, 
Rl+E%
*/Οbu~%tYM3A<if!"&3eMO1]30Qi1 -C3%<\A XkǿDa	iޑ(R@
\$G(69laT'&6Th1JVH׫{=*;9y
sd~wdUn̳ڌA:Lc{<Fela`^ia799)#[6;lG/wphC~aIVpFz(r%"'asnxoޣYe~?f>1wNxׯeGG2r{ߔi޽:#֫z\"PsEF9eFi|tV"bǞW
	J+tAݔ`|ZXwnK-WUeJUeUeya/Z/-k^{+_S!VO[<=;b/:>OsJ<VW^} ,ZB\K`w7Fq_./^<S*	èwl-ŷ052ި;tk-yq}{It2םwq/MvV\aDiC"p+`D\ڙ@4B12-s&!؝g|T4؍}`둨Tr}D=m;rP3'oPQM3(jv\dij\sfmL,o)97tFۑ9=qO5)EU;0
Y[f]ϟG	41mYe}7(J$
8yRklbrnMf~7d#XlR7?arcr
Hk"c:p~tv&GFKo卒\T.	&,ȱdi4ƍ!M5n`-B7
}maS2Y;קf/Ma	ͭ,#T{
Z}do*&kc&A!Cwz,ZEKȇZY$!#IxˣBэw x{sBl5R)U-ϯR?<A9TdC=bًL(pXc%19=;z٫ r驅I72cWsdEu
<_-MXBAWO/̋Z噪]+
qKHA./ ݱ\e3y,I mXKHo:9>*`A4]6V<P0V.ބT\HCURJR[fNusV|-GKD	Pgt\z0҃Fb$K9-y鹠>LJΒ0f0/C9f	%Dgc8	%\B"9܂b/#q$Vr7E'1<tmi+\a#W,W}*Ġ\ ~f
<"p9C ~<Dyg;atڋsBUAt#+oHQW<1'Bpg*NOrKXW9[Q*JCpd;;$L7'i/05n^K	_dѬ661A7؟<7|K%}xX"*lM1F?.-7r
A'	
sD^Kk
D @km*+o`_ܮNs?]/p/<Fc]-բFI9@A]Wi+Ein ZXNqO[xT୒!J8+◽yꝴoׅێoA9haP`	Q!,kn)ޒtȓyK~Hţ&F@p	/
4ieom	:3oDϘm%g SdȨ	i8}[]~2lͿ2Rd+CV\++i,GG8@6B0We"ݘu ړ247gCn;z&,
d~;f9׆29b;}KziI)A%)I*'b=CZ4, \I@"-B93ʩF59$4	@888aC=u '#BImsQfj.-JK̸Ĕe	Egx]#/FEū&8pS{'WOםb4 [M]BGBB3/)c.nKG;{=H/Vp7SSX9Z(ZZ|B{RP"	{EJW۵]qO`"ޣ݆`/A&=_w`z;?L!u  Z%v8
aKrîD(Ky4KHĽD[7%nY{Eu2MFf1hgƾ=qY:`b'(7d#Q|#kt,syr	%K*X$BG>::BzNG!yyySN̷]=;+1pJ=FNR`hzbZz4,#5Je`f3SJ3h<7	F2j(<3Rם0G1[jn吴nG_-4WQW}ӤYux-GxoV/ 1mG+9*қԑntdty\Gzo9,"?D3~>\`nHK`hQ8śjhnw%ѲKiFPQ>g[P)YHxFȾZ]n"̙E84|&*<&޽L)ƫE4wŭY3#B	mؓEU
iRʾ8N\ G =_)C7صn[c\hzbfF	- s?	KZ`Bmxc"N߹< /jilXcfݪ9ǪF0Ki$`#-"s{\(ovJ'jxWUP%C1t|gej
Ֆ{ʛhf*avս
$Y7hYzz[^5)߈qeУ6zgۗzQgSÛ:ǲ-}[Q~mQVds$Q-lۥ}cY{j1l̸jĢk~	{@]n&z_BQ62kڣ^:*?%.daqmZX3o}yl^UJC=9xrD< pXDya#RB?p$_l?|-*dfeTs*qCTc|m<Qq8n(iLDTfĀ蠍u
APsܝ/Qk0\ua^:=&9⪅y*?
Cpf*6K%jBV3LR eT#*6~ǫY<m"
953s ;OSuP`R_*Ctgg'hB!2 ~#^.mUSP
BxTthdZ-Ϟ/^1z1iAVePRq~|
g}L)NHTA;W9rp%U`S?cU=ꢄY1b J p];i1ձ8A= I/Xdj|M3̔g3f.5_(ǋ4=&@u]\|1J3mx/JivL(+$xp1{aBoֈJ('{!,AGbzQMბojEL-ؔ8Y_.턂Nh<|-yNK0,HhEbp͢e
:;ZfkBmF0p֩=>)%/$i .Gk76EQ2sAY^B!$r*S#Bw)f
7b0mQ~VQ!v3&oifdh-mmN6'i^B.[`\f [q)	㶀ڪf6iY#(P[Af-~:E]Wxu)Ӷ9JXe$hn15ͽ0Wű܄ZS.dW~Z'~oi
݄oMqlYkۤd;oji=H1sm"6L.+6w`u;̷ "0Nyf/&gK)M`݁Allڙu5#о|^oj8Og}zS`ݘpIj
)@kN*Q==G1 +y!O-kW%+T;(YNj샃]T_L{Z`f֩QW>`%p<llDvGI'0NѣzGOӿ36g
V{uh(+=bƏ+f?rg;gSǶ?)M ,;8U[;IsBA)MnvB
TW*I0`~4iUwF"X!g~C=YX#U݂(65!yQ9Vxp?($Ȃ Y;&kS9iD)]NL;3Յ9DӹyY64xo'ﲒK&K#JyߐɏKaHA9DTb>*q$*BTFbL,\.+ ׂ._{^^bDv[>eTH>wuVs>mP0ַҥ2Og
=

x56|(e6bRyazC#>j!|Z59]z'`z[kL/XcZ!O&TqdO^ NF "2|MQ]Qٗȇ?Ǣ9E+2>"0Vp(j N19&K`uE/A>YКWDSf "؁HSe#AhҠ$.Gr
]
]h`&.+|h,$oXE0[&c00[&L"fdLdLƹh[l|IGdLkdD
̄ɸ:[N"ÄԑP5ʂ`DAI~"W%"0U%	&j¼E¿Sw§0ËX.KZFpղG*H"SzyI	'z!4.
k9z}<46~2'k߳Nfh$%	؇*~8u=c)v,gN'x2
-IK2rQu&ջiN#sܲgs\)[˾[
|)-Ǿ|6QDyb@?z?ATqI{РqFW;Pe:
:I cb`G*ԏb=>~ɛNa᝖;V$-Ji5wX+RiG^ri)iÛ؜z=t˳%Fb OKX,ji\2Ĵq?5|Uߊ"6W]^Hq(2erD<ľJ^?`$C iE'E0} v;NnNTQǚyk˔Y.ʍ
1}%yX3uK}@Z~>4gTʙ9Lbi)*z1tzIB.SҘOهF#mJ-YL5&-ms1o?4xZV32^<3dȷl_Ftͣ=&"	5h,JԵXFhU\lɈ&܃;
e{roWj9vM=/SX]39&_X8J4_EjDjR ccUKtWCmt^Xzov_ʲ:o7I1{fkm07ɬkqFwlWFu0I|('LiГyuZ]NXld;=:8tR\B2+iauGQ̫63
K}@*g%)<GnG
|B~=j\3JN'fA;zSky
u18)O0se[1ȯӂ1ϯGKÊדᓒQߣS*HM݊$wa(þˡOs09CVp !?XGJleY+ҡ:C\IFm	u%Chqy}3=Hm_"ȕM^(6EZ//\"(!ިX̃c mv  R؅)
J'OR!qW-%ePQxFmC0g3K} J^HԢO2	 BWAo.KwngؖJ䁖ayUikprWh
EI8Q0b
+9S |ڇxMzi
Bsřぽ	|IõziF[u"3xip)SW2ދ06-7B;W_PPJ0~3de/.;+Q[P'*JP?F~{2Ǟ	D}G,*AdK^i^ԤjR*?P9ëw e0zȻ_xUZAh
qT6}IwFFuFͱ%G@Gy<	[c$|(42k(y%{QTL~lKs~wE<ҁ)*87OጝT:<[IS)bL'76l%z@LiYx;ư1-DolP]L^w
*xTrjQMj~x!HNlB?3fH<;lagIe	%&v@ϔpHR)=PF 7~CfxUJVlHo6?	c
eyT,e[,Ai87>|j)KSC=P3tȖd	JI0ml!XSUeΏjA5EɰVjJ7R:o*DZ_P-G(UfǥfbxL#krf]C@m!Zc 8y
\E}o=ɜ rZѼiHx@n85>&M;Et	爲Mn>6Bvdh<3eoQ|kz;,Y2в7%ۏ7SlM|<gkз)d뻖8d`Y
7{W,PnZkY"-qȒړoƀD&Oi
?`%q[(ڂaz;iÒűonŉEGYEJlYװ|Oi6V^6F^X\jQꑘ3#[U&FܺSC"L$Tȕb 2d 	}lf{%ŃAgv8s%jS}:>f.oonbn9t1[Xi`&{/'Y
ZǂBΟŧ/=1C<&V$o唚+.qA
#HȆr%N/ͦysPܼn4#"{+nZ#/ZkK*K\M
Vy7mmϙEv<ƆVac>/I-i.&scDƸ̭ټf3xIxdyS\ueysDqFd
lz|)F@٥)S=Sxx
	2Yk{?x̹?o"/%FXϻYB?}H_*'9y2!(7::Sz4W*34[LW07`0e -eCld<KTo
'Cv5mPruzƓA#L`)1I,pLBݑR8wj~zVt+i<4;U+T>f/M]d%kGX
2?hMӳ{:!kђu
SH~GZVOBk,b=}4&raȬTI||pC8LAPo,ߩp'zޟ?`nF;wţ;I*fo)/Ȉo_Mji4 9.Gl
Hؽ
J3'S0y|B*xutSߋmm[!%/<)$l%k
9q4vQ7uԶu>`ܑ<Ii~9TT<5/-_8h/qk~5ф9j\PHHNu$kq <JY̏Yf+	^R!Os(9@<owqHȖ!iy܆>h	bQMKUzd`Y9׼\i
~0B-k.K}boթ&c0Z{Io D=TbMDXBt}	)ƬVHW	W	Wx 雕݊gƥihy
D>tK߇}!60f}qs=QP݇(COTaF[mG.]|)#n1t6!5AHCX)ݜ@[{Wj,Ǖ# dFRR~.
w;vV0>/uɝ8(3ix"TLH1	>FK[>\+ů_ vsv8O+jYS{v>F:
J9I?Y)#ky%I|(ҝH!"b9hϹϾOr]fG"`_sBl`!~kXJ\lⷿA?@e2UZ1O~*UeTXĆYO-+]}|zM5q<Imu(:f<0hyg2#9ԳM~D?G-Ҟ1״~ʧ3YN
NN
X,x]g* _4M!GsyOݧ%. gP[DC[j՛BuHy
ͱA>l%uvٻ]`R]5ZZ
<p{䵁8y]`u8g֫Cz!/R{f<?&7%!ubf8oȒ:gB1vij
3=A1	y@yЎ?S$4BZYtJ]9Ȁ:8&4toUj?.^G.*\RKi(p؅e׋ؔ=kb1Qڭ\JQ`+yTw@
D1+y4Yu8ղ2ogʹcKSo9FܩL=q=П$gR5xYAukK]AۿRsz!~^;(~kPrK{ϭ2ekmUs6hgN7ʧrQI2GE@#4&ְt2zҐRJ8yvG	ۣk8&9ʡm[Y4[uG@6w}&y]snuPXīZ?R7kyqM
z`S6cO๩xqyg8ĂsH^fs+t2Gơ*΅s3)p)3WT%>7zȀQq`Zŉi1uUF&	qKYhF<9ٳ0ⲩ<ΫB`Z.F5/Ezg#85=E<h7{D}'7kR*g״}[Vh~n*9}{Lw'2SsH̌oWudflsw^~+mSW^l_XWf53W<pL21i_Ws&N ڧ=<|,37._̇\Md֔[knּkn5]'Ik49ڼi$/(b`uy`b
@.>l:MuN"vBYaMxm9I6K؏^@{DVn빍nN#e_K62J%%=Yj麻X^z\'n
ZףctXJ`5+A3^Vk
o}聪9E5'uͤ l.ZK#^Z\\dMCW]Fϛ?֥ ٛ	`$pT`TIGiavp3><kz7Sz֗5
%d]
-c^ץh^sw
c*5
{7#`{avIA*U#4Ն:CM8!tk4}8OG+u,VO<v(raQ63+{?sj/fuÿ[/u6zژ<sXJL9! 8ܯ9dg z]9O2㗄۾ՕHi	ެp)gskX%Y7[qϷ/d9~?d:C;s)YeOG8&#[} g ©ќw\iRc2%ͮտNL
q
siu
u<$z̝tBnsoG0(ƿGQ)~ȧ0YE$:S?O2mJQF>NT8f<tjxe'Y|}uAz/7?	>Մ,A }IP$*|LQ*xwb󧺡$vצ4 	;KEmlO3L oI}
+Q&3;-zGRt$CPY1UޔwFf0hU}ʿ@V1 ho0SC`N`xlEI4IN9	Xl5DVCI-M/v@7.yͥ
l("R"" 2Dnnj^g'R3`~=yw#}& zNN#Xx;^op>p@>qڕ.Wͪ/Y%Jh}H!ч܆0U"OVL*TfOD5ӌfB~.q
«
Kw߬cYkfֿ-~,Ѩ`RIo{7PX@܏!.?
c!λ81Wt7 X5ZڠFךw:o濭ky'f==s7+bvfgW/%辏%!yI{qջCĘ^1G16 1Ӵu+Q9M[)W:1gG0f8Ӝv*Ǳ6eN.G;A8KvM3L)y[:/,8n[7į蹻щcyӹۮ[Qjeg"*dpD tZ/,Xn)]تu<)vY,<sw]W[Fր]Zg&
	lu<S8}mnD?RWgE6c&gCp]U?":&eHLr-5wt% {)2E|+Ky+liو5Ȳ	kc^#^f[M
Yc=?
__CPAN_COMMON__ Storage_version6.swf
CWS  xڬXKo>$+q	cē8ddZ@:k& M-]L(R )'꦳]A7EWtٟЅ{ uyϹ}w};~eOKW&>qr}Ip
go	Α>o½	owK<~`8Jv\?Dpw$^pCgnķ1Dl0CzĊx(
GEa@7bnd*<؎
ƴbiC#£F/$
NFa&!8α}un˰^Ct7aM16Q|w=칉or/vqXCWg6y,Q:wv:OCpr{0'QfOb*qlG;SM0ppﻘXK&:PQKESkFGڤ,d	QbMwȩZV\jEQ+sTQ\jUQs0Kbw] ,#AO.[yr%}m~6t-
} JuEů\=6C_򯷹Pzh_JyׄBt]R M\y!ɳQyq7:Sr7q88oΫ;S0YbtBd|6$=emG{)iB*7nqOqn%8.OլL9W,ƖOkxEx4˅~ ӮJ="乢W+k	R}!`^e+/2YfSBQ4ҫR:ӫY8Sz/D{@KN|PFpaĠ6a;R$FF2?K^Ou*ϥ¶':dk<3'e~}dU>V[t-ZCٲY>LbwOACh%zn8A;;)@a/tf7ހErVNuqp11@tf8^xp,9{vPFGO%(@L
#E-tr_yN!=
9F}
C7Q-`鏂n⅁(@n;CBm(')~~A[|RrFnw>l{3aD|?;N>
  R]zÛQR7C-"h	CmJ&gX&qEXд4IKV"X Ko.ܶoW2eN"Q4n0bq`ǡح"tLsͬoX
'3_Z?r<VXK<m9e<7ZMi,lNW0 un#;571`K9c@~òQޟp̳)\N`ښ/Qَ@<P֮K9E"qʳ¡92u*9DJBڐT_H{|0O	V#ab
E}^
tC&V߮|)M]
&ݜ5ԟuWA|IȪd|0]."{VlqyDW9r1:S	+BjOPM}[2brѻ]ٜ8,GA=-/,YB锄ԍp<)X͟@<䝲
頖y,] TC# >nsEP|!Y,4\,K"!B&d$=;M(JtAPK$oZ6|em~vgyݴ 9[D/2N    'd
__CPAN_COMMON__ Storage_version8.swf
CWS   xڬn+8V8N$v1iv2BmɐhPJRvUvBhWbtS
{IQ4Iz!{{P?@ Mr<_wzs[w}`zn_ӫ&MnsA*u=mhznM,
,ݶ~g(zpu3w7=
ipvޛUٺ	놱4Q͠jަWo5L'zrޅm=БEaJf]ө@&vc{Xl6vu4%5|R0G;h*(91#7=O?=-Ro6Sh9Y,;s|/e>]5-֡xSXmTD>)5mx
˰7a%$Zq&7m[rn gá%l5,`s/m2?)4_$h͸
mL)"U¬?L'
LKMdIy
*,U'1X)+oХN`~'1aL}tc0fb3ad>B§1r fENb*5\)+
?^AKCr
aAoZ<84ڕ+[ [kj3
|)mdK&Ifsm̖
zD5}Kvbd[Ƹ4Zr֜v]&W
_q{)hIR9O1p' -Y4-8q*Z(0j	%vTT%ϕm(@gij/XS`6Ll54
R.e(1'3@a0+aAck$zBX 4՞r-4f<O?p_Ûє.-ܚEC.*X=G*BѦ۳\>/FOsdCyi%.zB(/!.M^ty~^7K3QmL`DlL7>~<;#
`"|WJ"sJfWbc7ze,F
]_xNSr!c$
X&  EGB/D0P^l
]w-]vo}|}, POlC_=%zvZ;5^{FP}i3z}dX}aB
\{Id 03rB)  ǀ=)({.I#AX7^H@dzLi|쇒MRͧVc_REV"FؑcGƎD|(8h|xf8Z<bcڡg# ^lSS݆{5_B}u\vUġdNcܲfwp9F	26
.t4ojuqyŮ=hش ^8^§jS/7;ۃqt]Na;_x5ܪVq򛭭rYR\+udNI4<Д,ʧ~`6Hc:<uMO1]IDYY#D04E_x"{y:"OGij)liZ^-pgRVq' b%6L
L)2A$j#Qעqp7y|d`DbesZ≠'hV4J{5W@Pf>mZbeQ6b]B!ly=t\ o@^5.  UҺXjOXJh"oDiܤ; \v3b{[A5 b z
W#Bg
;^1>m~(C VPk_HJ&y3ӂCpa}AG*slw['B4l泿{'ܼ[
]QSËfq1[=q=Q!kv_v|b/_gEȯEv+Tߕx}{;q?$juxo۫S{i;#\Ai'56L].,VYmyVp
=vP$#WmB^Ng}ە7,=kJj-XC:s;
|͍7[:(f]
z8Ѭc;WX]a
S].&ՏuY`#)BʷWaujCePܝLa*h|Ty|` %Z
/To>C=X0Ni8ZrÎ>t~!Қ*ũ(	M)V팠MtB0^Ų;}b?#߼hؽHJw 
Ux[_I³,]*l]~%tҿ]\$oPpum-2M^,s%5Ӟ2_,%k\>^&wd4x
MzU U8$POqJKN7bE/    s
__CPAN_COMMON__ README
The Dojo Toolkit
----------------

Dojo is a portable JavaScript toolkit for web application developers and
JavaScript professionals. Dojo solves real-world problems by providing powerful
abstractions and solid, tested implementations.

Getting Started
---------------

To use Dojo in your application, download one of the pre-built editions from the
Dojo website, http://dojotoolkit.org. Once you have downloaded the file you will
need to unzip the archive in your website root. At a minimum, you will need to
extract:

    src/ (folder)
    dojo.js
    iframe_history.html

To begin using dojo, include dojo in your pages by using:

    <script type="text/javascript" src="/path/to/dojo.js"></script>

Depending on the edition that you have downloaded, this base dojo.js file may or
may not include the modules you wish to use in your application. The files which
have been "baked in" to the dojo.js that is part of your distribution are listed
in the file build.txt that is part of the top-level directory that is created
when you unpack the archive. To ensure modules you wish to use are available,
use dojo.require() to request them. A very rich application might include:

    <script type="text/javascript" src="/path/to/dojo.js"></script>
    <script type="text/javascript">
        dojo.require("dojo.event.*");       // sophisticated AOP event handling
        dojo.require("dojo.io.*");          // for Ajax requests
        dojo.require("dojo.storage.*");     // a persistent local data cache
        dojo.require("dojo.json");          // serialization to JSON
        dojo.require("dojo.dnd.*");         // drag-and-drop
        dojo.require("dojo.lfx.*");         // animations and eye candy
        dojo.require("dojo.widget.Editor2");// stable, portable HTML WYSIWYG
    </script>

Note that only those modules which are *not* already "baked in" to dojo.js by
the edition's build process are requested by dojo.require(). This helps make
your application faster without forcing you to use a build tool while in
development. See "Building Dojo" and "Working From Source" for more details.


Compatibility
-------------

In addition to it's suite of unit-tests for core system components, Dojo has
been tested on almost every modern browser, including:

    - IE 5.5+
    - Mozilla 1.5+, Firefox 1.0+
    - Safari 1.3.9+
    - Konqueror 3.4+
    - Opera 8.5+

Note that some widgets and features may not perform exactly the same on every
browser due to browser implementation differences.

For those looking to use Dojo in non-browser environments, please see "Working
From Source".


Documentation and Getting Help
------------------------------

Articles outlining major Dojo systems are linked from:

    http://dojotoolkit.org/docs/

Toolkit APIs are listed in outline form at:

    http://dojotoolkit.org/docs/apis/

And documented in full at:

    http://manual.dojotoolkit.org/

The project also maintains a JotSpot Wiki at:

    http://dojo.jot.com/

A FAQ has been extracted from mailing list traffic:

    http://dojo.jot.com/FAQ

And the main Dojo user mailing list is archived and made searchable at:

    http://news.gmane.org/gmane.comp.web.dojo.user/

You can sign up for this list, which is a great place to ask questions, at:

    http://dojotoolkit.org/mailman/listinfo/dojo-interest

The Dojo developers also tend to hang out in IRC and help people with Dojo
problems. You're most likely to find them at:

    irc.freenode.net #dojo

Note that 3PM Wed PST in #dojo-meeting is reserved for a weekly meeting between
project developers, although anyone is welcome to participate.


Working From Source
-------------------

The core of Dojo is a powerful package system that allows developers to optimize
Dojo for deployment while using *exactly the same* application code in
development. Therefore, working from source is almost exactly like working from
a pre-built edition. Pre-built editions are significantly faster to load than
working from source, but are not as flexible when in development.

There are multiple ways to get the source. Nightly snapshots of the Dojo source
repository are available at:

    http://archive.dojotoolkit.org/nightly.tgz

Anonymous Subversion access is also available:

    %> svn co http://svn.dojotoolkit.org/dojo/trunk/ dojo

Each of these sources will include some extra directories not included in the
pre-packaged editions, including command-line tests and build tools for
constructing your own packages.

Running the command-line unit test suite requires Ant 1.6. If it is installed
and in your path, you can run the tests using:

    %> cd buildscripts
    %> ant test

The command-line test harness makes use of Rhino, a JavaScript interpreter
written in Java. Once you have a copy of Dojo's source tree, you have a copy of
Rhino. From the root directory, you can use Rhino interactively to load Dojo:

    %> java -jar buildscripts/lib/js.jar
    Rhino 1.5 release 3 2002 01 27
    js> load("dojo.js");
    js> print(dojo);
    [object Object]
    js> quit();

This environment is wonderful for testing raw JavaScript functionality in, or
even for scripting your system. Since Rhino has full access to anything in
Java's classpath, the sky is the limit!

Building Dojo
-------------

Dojo requires Ant 1.6.x in order to build correctly. While using Dojo from
source does *NOT* require that you make a build, speeding up your application by
constructing a custom profile build does.

Once you have Ant and a source snapshot of Dojo, you can make your own profile
build ("edition") which includes only those modules your application uses by
customizing one of the files in:

    [dojo]/buildscripts/profiles/

These files are named *.profile.js and each one contains a list of modules to
include in a build. If we created a new profile called "test.profile.js", we
could then make a profile build using it by doing:

    %> cd buildscripts
    %> ant -Dprofile=test -Ddocless=true release intern-strings

If the build is successful, your newly minted and compressed  profile build will
be placed in [dojo]/release/dojo/

-------------------------------------------------------------------------------
Copyright (c) 2004-2006, The Dojo Foundation, All Rights Reserved

vim:ts=4:et:tw=80:shiftwidth=4:

__CPAN_COMMON__ LICENSE
Dojo is availble under *either* the terms of the modified BSD license *or* the
Academic Free License version 2.1. As a recipient of Dojo, you may choose which
license to receive this code under (except as noted in per-module LICENSE
files). Some modules may not be the copyright of the Dojo Foundation. These
modules contain explicit declarations of copyright in both the LICENSE files in
the directories in which they reside and in the code itself. No external
contributions are allowed under licenses which are fundamentally incompatible
with the AFL or BSD licenses that Dojo is distributed under.

The text of the AFL and BSD licenses is reproduced below. 

-------------------------------------------------------------------------------
The "New" BSD License:
**********************

Copyright (c) 2005-2006, The Dojo Foundation
All rights reserved.

Redistribution and use in source and binary forms, with or without
modification, are permitted provided that the following conditions are met:

  * Redistributions of source code must retain the above copyright notice, this
    list of conditions and the following disclaimer.
  * Redistributions in binary form must reproduce the above copyright notice,
    this list of conditions and the following disclaimer in the documentation
    and/or other materials provided with the distribution.
  * Neither the name of the Dojo Foundation nor the names of its contributors
    may be used to endorse or promote products derived from this software
    without specific prior written permission.

THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS "AS IS" AND
ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED
WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE
DISCLAIMED.  IN NO EVENT SHALL THE COPYRIGHT OWNER OR CONTRIBUTORS BE LIABLE
FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL
DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR
SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER
CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY,
OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE
OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.

-------------------------------------------------------------------------------
The Academic Free License, v. 2.1:
**********************************

This Academic Free License (the "License") applies to any original work of
authorship (the "Original Work") whose owner (the "Licensor") has placed the
following notice immediately following the copyright notice for the Original
Work:

Licensed under the Academic Free License version 2.1

1) Grant of Copyright License. Licensor hereby grants You a world-wide,
royalty-free, non-exclusive, perpetual, sublicenseable license to do the
following:

a) to reproduce the Original Work in copies;

b) to prepare derivative works ("Derivative Works") based upon the Original
Work;

c) to distribute copies of the Original Work and Derivative Works to the
public;

d) to perform the Original Work publicly; and

e) to display the Original Work publicly.

2) Grant of Patent License. Licensor hereby grants You a world-wide,
royalty-free, non-exclusive, perpetual, sublicenseable license, under patent
claims owned or controlled by the Licensor that are embodied in the Original
Work as furnished by the Licensor, to make, use, sell and offer for sale the
Original Work and Derivative Works.

3) Grant of Source Code License. The term "Source Code" means the preferred
form of the Original Work for making modifications to it and all available
documentation describing how to modify the Original Work. Licensor hereby
agrees to provide a machine-readable copy of the Source Code of the Original
Work along with each copy of the Original Work that Licensor distributes.
Licensor reserves the right to satisfy this obligation by placing a
machine-readable copy of the Source Code in an information repository
reasonably calculated to permit inexpensive and convenient access by You for as
long as Licensor continues to distribute the Original Work, and by publishing
the address of that information repository in a notice immediately following
the copyright notice that applies to the Original Work.

4) Exclusions From License Grant. Neither the names of Licensor, nor the names
of any contributors to the Original Work, nor any of their trademarks or
service marks, may be used to endorse or promote products derived from this
Original Work without express prior written permission of the Licensor. Nothing
in this License shall be deemed to grant any rights to trademarks, copyrights,
patents, trade secrets or any other intellectual property of Licensor except as
expressly stated herein. No patent license is granted to make, use, sell or
offer to sell embodiments of any patent claims other than the licensed claims
defined in Section 2. No right is granted to the trademarks of Licensor even if
such marks are included in the Original Work. Nothing in this License shall be
interpreted to prohibit Licensor from licensing under different terms from this
License any Original Work that Licensor otherwise would have a right to
license.

5) This section intentionally omitted.

6) Attribution Rights. You must retain, in the Source Code of any Derivative
Works that You create, all copyright, patent or trademark notices from the
Source Code of the Original Work, as well as any notices of licensing and any
descriptive text identified therein as an "Attribution Notice." You must cause
the Source Code for any Derivative Works that You create to carry a prominent
Attribution Notice reasonably calculated to inform recipients that You have
modified the Original Work.

7) Warranty of Provenance and Disclaimer of Warranty. Licensor warrants that
the copyright in and to the Original Work and the patent rights granted herein
by Licensor are owned by the Licensor or are sublicensed to You under the terms
of this License with the permission of the contributor(s) of those copyrights
and patent rights. Except as expressly stated in the immediately proceeding
sentence, the Original Work is provided under this License on an "AS IS" BASIS
and WITHOUT WARRANTY, either express or implied, including, without limitation,
the warranties of NON-INFRINGEMENT, MERCHANTABILITY or FITNESS FOR A PARTICULAR
PURPOSE. THE ENTIRE RISK AS TO THE QUALITY OF THE ORIGINAL WORK IS WITH YOU.
This DISCLAIMER OF WARRANTY constitutes an essential part of this License. No
license to Original Work is granted hereunder except under this disclaimer.

8) Limitation of Liability. Under no circumstances and under no legal theory,
whether in tort (including negligence), contract, or otherwise, shall the
Licensor be liable to any person for any direct, indirect, special, incidental,
or consequential damages of any character arising as a result of this License
or the use of the Original Work including, without limitation, damages for loss
of goodwill, work stoppage, computer failure or malfunction, or any and all
other commercial damages or losses. This limitation of liability shall not
apply to liability for death or personal injury resulting from Licensor's
negligence to the extent applicable law prohibits such limitation. Some
jurisdictions do not allow the exclusion or limitation of incidental or
consequential damages, so this exclusion and limitation may not apply to You.

9) Acceptance and Termination. If You distribute copies of the Original Work or
a Derivative Work, You must make a reasonable effort under the circumstances to
obtain the express assent of recipients to the terms of this License. Nothing
else but this License (or another written agreement between Licensor and You)
grants You permission to create Derivative Works based upon the Original Work
or to exercise any of the rights granted in Section 1 herein, and any attempt
to do so except under the terms of this License (or another written agreement
between Licensor and You) is expressly prohibited by U.S. copyright law, the
equivalent laws of other countries, and by international treaty. Therefore, by
exercising any of the rights granted to You in Section 1 herein, You indicate
Your acceptance of this License and all of its terms and conditions.

10) Termination for Patent Action. This License shall terminate automatically
and You may no longer exercise any of the rights granted to You by this License
as of the date You commence an action, including a cross-claim or counterclaim,
against Licensor or any licensee alleging that the Original Work infringes a
patent. This termination provision shall not apply for an action alleging
patent infringement by combinations of the Original Work with other software or
hardware.

11) Jurisdiction, Venue and Governing Law. Any action or suit relating to this
License may be brought only in the courts of a jurisdiction wherein the
Licensor resides or in which Licensor conducts its primary business, and under
the laws of that jurisdiction excluding its conflict-of-law provisions. The
application of the United Nations Convention on Contracts for the International
Sale of Goods is expressly excluded. Any use of the Original Work outside the
scope of this License or after its termination shall be subject to the
requirements and penalties of the U.S. Copyright Act, 17 U.S.C. Â§ 101 et
seq., the equivalent laws of other countries, and international treaty. This
section shall survive the termination of this License.

12) Attorneys Fees. In any action to enforce the terms of this License or
seeking damages relating thereto, the prevailing party shall be entitled to
recover its costs and expenses, including, without limitation, reasonable
attorneys' fees and costs incurred in connection with such action, including
any appeal of such action. This section shall survive the termination of this
License.

13) Miscellaneous. This License represents the complete agreement concerning
the subject matter hereof. If any provision of this License is held to be
unenforceable, such provision shall be reformed only to the extent necessary to
make it enforceable.

14) Definition of "You" in This License. "You" throughout this License, whether
in upper or lower case, means an individual or a legal entity exercising rights
under, and complying with all of the terms of, this License. For legal
entities, "You" includes any entity that controls, is controlled by, or is
under common control with you. For purposes of this definition, "control" means
(i) the power, direct or indirect, to cause the direction or management of such
entity, whether by contract or otherwise, or (ii) ownership of fifty percent
(50%) or more of the outstanding shares, or (iii) beneficial ownership of such
entity.

15) Right to Use. You may use the Original Work in all ways not otherwise
restricted or conditioned by this License or by law, and Licensor promises not
to interfere with or be responsible for such uses by You.

This license is Copyright (C) 2003-2004 Lawrence E. Rosen. All rights reserved.
Permission is hereby granted to copy and distribute this license without
modification. This license may not be modified without the express written
permission of its copyright owner.

